==> core-components-checkbox-4.3.1.tgz: package/esm/Component.js <==
import { __rest, __assign } from 'tslib';
import React, { forwardRef, useRef } from 'react';
import mergeRefs from 'react-merge-refs';
import cn from 'classnames';
import { dom } from '@alfalab/core-components-shared/esm';
import { useFocus } from '@alfalab/hooks';
import { CheckmarkCompactMIcon } from '@alfalab/icons-glyph/CheckmarkCompactMIcon';

var styles = {"component":"checkbox__component_1jmge","start":"checkbox__start_1jmge","center":"checkbox__center_1jmge","addons":"checkbox__addons_1jmge","block":"checkbox__block_1jmge","box":"checkbox__box_1jmge","checkedIcon":"checkbox__checkedIcon_1jmge","size-20":"checkbox__size-20_1jmge","disabled":"checkbox__disabled_1jmge","checked":"checkbox__checked_1jmge","indeterminate":"checkbox__indeterminate_1jmge","indeterminateLine":"checkbox__indeterminateLine_1jmge","label":"checkbox__label_1jmge","hint":"checkbox__hint_1jmge","focused":"checkbox__focused_1jmge","content":"checkbox__content_1jmge","errorMessage":"checkbox__errorMessage_1jmge"};
require('./index.css')

var SIZE_TO_CLASSNAME_MAP = {
    s: 'size-20',
    m: 'size-24',
    20: 'size-20',
    24: 'size-24',
};
var Checkbox = forwardRef(function (_a, ref) {
    var _b;
    var checked = _a.checked, label = _a.label, hint = _a.hint, _c = _a.size, size = _c === void 0 ? 20 : _c, boxClassName = _a.boxClassName, contentClassName = _a.contentClassName, _d = _a.align, align = _d === void 0 ? 'start' : _d, addons = _a.addons, block = _a.block, onChange = _a.onChange, className = _a.className, name = _a.name, disabled = _a.disabled, inactive = _a.inactive, dataTestId = _a.dataTestId, _e = _a.indeterminate, indeterminate = _e === void 0 ? false : _e, _f = _a.hiddenInput, hiddenInput = _f === void 0 ? false : _f, labelProps = _a.labelProps, error = _a.error, inputRef = _a.inputRef, restProps = __rest(_a, ["checked", "label", "hint", "size", "boxClassName", "contentClassName", "align", "addons", "block", "onChange", "className", "name", "disabled", "inactive", "dataTestId", "indeterminate", "hiddenInput", "labelProps", "error", "inputRef"]);
    var labelRef = useRef(null);
    var focused = useFocus(labelRef, 'keyboard')[0];
    var handleChange = function (event) {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name: name });
        }
    };
    var errorMessage = typeof error === 'boolean' ? '' : error;
    return (React.createElement("label", __assign({}, labelProps, { className: cn(styles.component, styles[SIZE_TO_CLASSNAME_MAP[size]], styles[align], className, labelProps === null || labelProps === void 0 ? void 0 : labelProps.className, (_b = {},
            _b[styles.disabled] = disabled || inactive,
            _b[styles.checked] = checked,
            _b[styles.indeterminate] = indeterminate,
            _b[styles.focused] = focused,
            _b[styles.block] = block,
            _b)), ref: mergeRefs([labelRef, ref, labelProps === null || labelProps === void 0 ? void 0 : labelProps.ref]) }),
        !hiddenInput && (React.createElement("input", __assign({ type: 'checkbox', onChange: handleChange, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId, ref: inputRef }, restProps))),
        React.createElement("span", { className: cn(styles.box, boxClassName) },
            checked && React.createElement(CheckmarkCompactMIcon, { className: styles.checkedIcon }),
            indeterminate && !checked && React.createElement("span", { className: styles.indeterminateLine })),
        (label || hint || errorMessage) && (React.createElement("span", { className: cn(styles.content, contentClassName) },
            label && React.createElement("span", { className: styles.label }, label),
            hint && !errorMessage && React.createElement("span", { className: styles.hint }, hint),
            errorMessage && (React.createElement("span", { className: styles.errorMessage, role: 'alert' }, errorMessage)))),
        addons && (
        // eslint-disable-next-line jsx-a11y/click-events-have-key-events,jsx-a11y/no-static-element-interactions
        React.createElement("span", { className: styles.addons, onClick: dom.preventDefault }, addons))));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };

==> core-components-checkbox-4.3.2.tgz: package/esm/Component.js <==
import { __rest, __assign } from 'tslib';
import React, { forwardRef, useRef } from 'react';
import mergeRefs from 'react-merge-refs';
import cn from 'classnames';
import { dom } from '@alfalab/core-components-shared/esm';
import { useFocus } from '@alfalab/hooks';
import { CheckmarkCompactMIcon } from '@alfalab/icons-glyph/CheckmarkCompactMIcon';

var styles = {"component":"checkbox__component_19s64","start":"checkbox__start_19s64","center":"checkbox__center_19s64","addons":"checkbox__addons_19s64","block":"checkbox__block_19s64","box":"checkbox__box_19s64","checkedIcon":"checkbox__checkedIcon_19s64","size-20":"checkbox__size-20_19s64","disabled":"checkbox__disabled_19s64","checked":"checkbox__checked_19s64","indeterminate":"checkbox__indeterminate_19s64","indeterminateLine":"checkbox__indeterminateLine_19s64","label":"checkbox__label_19s64","hint":"checkbox__hint_19s64","focused":"checkbox__focused_19s64","content":"checkbox__content_19s64","errorMessage":"checkbox__errorMessage_19s64"};
require('./index.css')

var SIZE_TO_CLASSNAME_MAP = {
    s: 'size-20',
    m: 'size-24',
    20: 'size-20',
    24: 'size-24',
};
var Checkbox = forwardRef(function (_a, ref) {
    var _b;
    var checked = _a.checked, label = _a.label, hint = _a.hint, _c = _a.size, size = _c === void 0 ? 20 : _c, boxClassName = _a.boxClassName, contentClassName = _a.contentClassName, _d = _a.align, align = _d === void 0 ? 'start' : _d, addons = _a.addons, block = _a.block, onChange = _a.onChange, className = _a.className, name = _a.name, disabled = _a.disabled, inactive = _a.inactive, dataTestId = _a.dataTestId, _e = _a.indeterminate, indeterminate = _e === void 0 ? false : _e, _f = _a.hiddenInput, hiddenInput = _f === void 0 ? false : _f, labelProps = _a.labelProps, error = _a.error, inputRef = _a.inputRef, restProps = __rest(_a, ["checked", "label", "hint", "size", "boxClassName", "contentClassName", "align", "addons", "block", "onChange", "className", "name", "disabled", "inactive", "dataTestId", "indeterminate", "hiddenInput", "labelProps", "error", "inputRef"]);
    var labelRef = useRef(null);
    var focused = useFocus(labelRef, 'keyboard')[0];
    var handleChange = function (event) {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name: name });
        }
    };
    var errorMessage = typeof error === 'boolean' ? '' : error;
    return (React.createElement("label", __assign({}, labelProps, { className: cn(styles.component, styles[SIZE_TO_CLASSNAME_MAP[size]], styles[align], className, labelProps === null || labelProps === void 0 ? void 0 : labelProps.className, (_b = {},
            _b[styles.disabled] = disabled || inactive,
            _b[styles.checked] = checked,
            _b[styles.indeterminate] = indeterminate,
            _b[styles.focused] = focused,
            _b[styles.block] = block,
            _b)), ref: mergeRefs([labelRef, ref, labelProps === null || labelProps === void 0 ? void 0 : labelProps.ref]) }),
        !hiddenInput && (React.createElement("input", __assign({ type: 'checkbox', onChange: handleChange, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId, ref: inputRef }, restProps))),
        React.createElement("span", { className: cn(styles.box, boxClassName) },
            checked && React.createElement(CheckmarkCompactMIcon, { className: styles.checkedIcon }),
            indeterminate && !checked && React.createElement("span", { className: styles.indeterminateLine })),
        (label || hint || errorMessage) && (React.createElement("span", { className: cn(styles.content, contentClassName) },
            label && React.createElement("span", { className: styles.label }, label),
            hint && !errorMessage && React.createElement("span", { className: styles.hint }, hint),
            errorMessage && (React.createElement("span", { className: styles.errorMessage, role: 'alert' }, errorMessage)))),
        addons && (
        // eslint-disable-next-line jsx-a11y/click-events-have-key-events,jsx-a11y/no-static-element-interactions
        React.createElement("span", { className: styles.addons, onClick: dom.preventDefault }, addons))));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
